"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hostingList = exports.enableHosting = exports.getHostingInfo = void 0;
const utils_1 = require("./utils");
const HostingStatusMap = {
    init: "初始化中",
    process: "处理中",
    online: "上线",
    destroying: "销毁中",
    offline: "下线",
    create_fail: "初始化失败",
    destroy_fail: "销毁失败",
};
const tcbService = utils_1.CloudApiService.getInstance("tcb");
function getHostingInfo(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { envId } = options;
        const res = yield tcbService.request("DescribeStaticStore", {
            EnvId: envId,
        });
        const data = utils_1.firstLetterToLowerCase(res);
        return data;
    });
}
exports.getHostingInfo = getHostingInfo;
function checkHostingStatus(envId) {
    return __awaiter(this, void 0, void 0, function* () {
        const hostings = yield getHostingInfo({ envId });
        const link = utils_1.genClickableLink("https://console.cloud.tencent.com/tcb");
        if (!hostings.data || !hostings.data.length) {
            throw new Error(`您还没有开启静态网站服务，请先到云开发控制台开启静态网站服务！\n👉 ${link}`);
        }
        const website = hostings.data[0];
        if (website.status !== "online") {
            throw new Error(`静态网站服务【${HostingStatusMap[website.status]}】，无法进行此操作！`);
        }
        return website;
    });
}
function enableHosting(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { envId } = options;
        const hostings = yield getHostingInfo(options);
        if (hostings.data && hostings.data.length) {
            const website = hostings.data[0];
            // offline 状态的服务可重新开启
            if (website.status !== "offline") {
                throw new Error("静态网站服务已开启，请勿重复操作！");
            }
        }
        const res = yield tcbService.request("CreateStaticStore", {
            EnvId: envId,
        });
        const code = res.Result === "succ" ? 0 : -1;
        return {
            code,
            requestId: res.RequestId,
        };
    });
}
exports.enableHosting = enableHosting;
// 展示文件信息
function hostingList(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { envId } = options;
        const hosting = yield checkHostingStatus(envId);
        const { bucket, regoin } = hosting;
        const storageService = yield getStorageService(envId);
        const list = yield storageService.walkCloudDirCustom({
            prefix: "",
            bucket,
            region: regoin,
        });
        return list;
    });
}
exports.hostingList = hostingList;
